#!/usr/bin/perl -T

use strict;
use warnings;

#*******************************************************************************
# Data::Cache::Memory module/class tests
#
# Author:   Jan Mach, jan.mach@cesnet.cz
# Version:  0.1
# Purpose:
#
#*******************************************************************************

use Data::Dumper;
#use Smart::Comments;

use Test::More tests => 15;

# First test if the module correctly compiles
BEGIN {
        use vars qw($TESTED_CLASS);
        $TESTED_CLASS = 'Data::Cache::Memory';

        use_ok('Tester');
        use_ok('Data::Cache');
        use_ok($TESTED_CLASS);

        $ENV{PATH} = '/bin:/usr/bin';
    }

# Debug output explicit ON switch
#Tester::DEBUG_ON();
#Tester::DEBUG_ON(10);

# Debug output explicit OFF switch
#Tester::DEBUG_OFF();

# User should know, which version is beeing tested (just for sure)
### $Data::Cache::Memory::VERSION

### Attempting to create Data::Cache::Memory instance...
my $instance = $TESTED_CLASS->new();
isa_ok($instance, $TESTED_CLASS);

### Viewing the created instance: $instance
diag("Instance dump 01: " . Dumper($instance)) if Tester::D(2);

my $testa   = ['array1', 'test', 'values'];
my $testb   = {a => '1', b => '1', c => '3'};
my $testc   = ['array2', 'test2', 'values2'];
my $exstats = {'hit' => 2, 'miss' => 1, 'aged' => 2, 'cached' => 3};

is($instance->cache('id1', $testa),    undef,                                     'Cache test 01');
is($instance->cache('id2', $testb),    undef,                                     'Cache test 02');
is($instance->cache('id1', $testc),    "Cache item for key 'id1' already exists", 'Cache test 03');
is($instance->cache('id1', $testc, 1), undef,                                     'Cache test 04');

my $test1 = $instance->fetch('id1');
my $test2 = $instance->fetch('id2');
my $test3 = $instance->fetch('id3');

is_deeply($test1, $testc, 'Fetch test 01');
is_deeply($test2, $testb, 'Fetch test 02');
is($test3,        undef,  'Fetch test 03');

sleep(2);
is($instance->fetch('id1', 1), undef, "Fetch-newer test 01");
is($instance->fetch('id2', 1), undef, "Fetch-newer test 02");

is_deeply($instance->stats(), $exstats, 'Stats test 01');

is($instance->clear(0), 'Deleted 2 cache objects older than 0.0000s', 'Clear test 01');
